# shofash.py 

shofash.py is a simple HTML compiler written in python3 that converts .txt source files into linked static .html pages. It is designed to be served as fast as it is possible for ultra-high visitor number informational websites: all pages are static .html, no scripting, no databases. It is also possible to use shofash.py alongside scripts and databases as required. 

